==> openshift-model-config-6.5.1-sources.jar: io/fabric8/openshift/api/model/config/v1/InfrastructureStatusFluent.java <==
package io.fabric8.openshift.api.model.config.v1;

import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public interface InfrastructureStatusFluent<A extends InfrastructureStatusFluent<A>> extends Fluent<A>{
  public String getApiServerInternalURI();
  public A withApiServerInternalURI(String apiServerInternalURI);
  public Boolean hasApiServerInternalURI();
  public String getApiServerURL();
  public A withApiServerURL(String apiServerURL);
  public Boolean hasApiServerURL();
  public String getControlPlaneTopology();
  public A withControlPlaneTopology(String controlPlaneTopology);
  public Boolean hasControlPlaneTopology();
  public String getEtcdDiscoveryDomain();
  public A withEtcdDiscoveryDomain(String etcdDiscoveryDomain);
  public Boolean hasEtcdDiscoveryDomain();
  public String getInfrastructureName();
  public A withInfrastructureName(String infrastructureName);
  public Boolean hasInfrastructureName();
  public String getInfrastructureTopology();
  public A withInfrastructureTopology(String infrastructureTopology);
  public Boolean hasInfrastructureTopology();
  public String getPlatform();
  public A withPlatform(String platform);
  public Boolean hasPlatform();
  
  /**
   * This method has been deprecated, please use method buildPlatformStatus instead.
   * @return The buildable object.
   */
  @Deprecated
  public PlatformStatus getPlatformStatus();
  public PlatformStatus buildPlatformStatus();
  public A withPlatformStatus(PlatformStatus platformStatus);
  public Boolean hasPlatformStatus();
  public InfrastructureStatusFluent.PlatformStatusNested<A> withNewPlatformStatus();
  public InfrastructureStatusFluent.PlatformStatusNested<A> withNewPlatformStatusLike(PlatformStatus item);
  public InfrastructureStatusFluent.PlatformStatusNested<A> editPlatformStatus();
  public InfrastructureStatusFluent.PlatformStatusNested<A> editOrNewPlatformStatus();
  public InfrastructureStatusFluent.PlatformStatusNested<A> editOrNewPlatformStatusLike(PlatformStatus item);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface PlatformStatusNested<N> extends Nested<N>,PlatformStatusFluent<InfrastructureStatusFluent.PlatformStatusNested<N>>{
    public N and();
    public N endPlatformStatus();
    
  }
  
}

==> openshift-model-config-6.7.2-sources.jar: io/fabric8/openshift/api/model/config/v1/InfrastructureStatusFluent.java <==
package io.fabric8.openshift.api.model.config.v1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface InfrastructureStatusFluent<A extends InfrastructureStatusFluent<A>> extends Fluent<A>{
  public String getApiServerInternalURI();
  public A withApiServerInternalURI(String apiServerInternalURI);
  public Boolean hasApiServerInternalURI();
  public String getApiServerURL();
  public A withApiServerURL(String apiServerURL);
  public Boolean hasApiServerURL();
  public String getControlPlaneTopology();
  public A withControlPlaneTopology(String controlPlaneTopology);
  public Boolean hasControlPlaneTopology();
  public String getEtcdDiscoveryDomain();
  public A withEtcdDiscoveryDomain(String etcdDiscoveryDomain);
  public Boolean hasEtcdDiscoveryDomain();
  public String getInfrastructureName();
  public A withInfrastructureName(String infrastructureName);
  public Boolean hasInfrastructureName();
  public String getInfrastructureTopology();
  public A withInfrastructureTopology(String infrastructureTopology);
  public Boolean hasInfrastructureTopology();
  public String getPlatform();
  public A withPlatform(String platform);
  public Boolean hasPlatform();
  
  /**
   * This method has been deprecated, please use method buildPlatformStatus instead.
   * @return The buildable object.
   */
  @Deprecated
  public PlatformStatus getPlatformStatus();
  public PlatformStatus buildPlatformStatus();
  public A withPlatformStatus(PlatformStatus platformStatus);
  public Boolean hasPlatformStatus();
  public InfrastructureStatusFluent.PlatformStatusNested<A> withNewPlatformStatus();
  public InfrastructureStatusFluent.PlatformStatusNested<A> withNewPlatformStatusLike(PlatformStatus item);
  public InfrastructureStatusFluent.PlatformStatusNested<A> editPlatformStatus();
  public InfrastructureStatusFluent.PlatformStatusNested<A> editOrNewPlatformStatus();
  public InfrastructureStatusFluent.PlatformStatusNested<A> editOrNewPlatformStatusLike(PlatformStatus item);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface PlatformStatusNested<N> extends Nested<N>,PlatformStatusFluent<InfrastructureStatusFluent.PlatformStatusNested<N>>{
    public N and();
    public N endPlatformStatus();
    
  }
  
}
